@@ -25,6 +25,7 @@
  */
 
 
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
@@ -44,8 +45,8 @@
 #include <signal.h>
 
 
-static char *version = "protoshoot 0.4";
-static char *help_msg = "\
+static char *version="protoshoot 0.4";
+static char* help_msg="\
 Usage: protoshoot -f file -d address -p port -c count [-v]\n\
 Options:\n\
     -f file       file with the content of the udp packet (max 65k)\n\
@@ -68,23 +69,17 @@ Options:\n\
 #define BUF_SIZE 65535
 
 
-enum protos
-{
-	PROTO_NONE,
-	PROTO_UDP,
-	PROTO_TCP,
-	PROTO_SCTP
-};
+enum protos { PROTO_NONE, PROTO_UDP, PROTO_TCP, PROTO_SCTP };
 
-int main(int argc, char **argv)
+int main (int argc, char** argv)
 {
 	int fd;
 	int sock;
 	char c;
-	int n, r;
-	char *tmp;
+	int n,r;
+	char* tmp;
 	char buf[BUF_SIZE];
-	struct hostent *he;
+	struct hostent* he;
 	struct sockaddr_in addr;
 
 	int count;
@@ -105,76 +100,76 @@ int main(int argc, char **argv)
 	int err;
 
 	/* init */
-	count = 1;
-	verbose = 0;
-	fname = 0;
-	dst = "127.0.0.1";
-	port = 5060;
-	usec = 0;
-	throttle = 0;
-	random_sleep = 0;
-	proto = PROTO_UDP;
-	tcp_rst = 0;
-	con_no = 1;
-	sctp_o2o = 0;
-	err = 0;
+	count=1;
+	verbose=0;
+	fname=0;
+	dst="127.0.0.1";
+	port=5060;
+	usec=0;
+	throttle=0;
+	random_sleep=0;
+	proto=PROTO_UDP;
+	tcp_rst=0;
+	con_no=1;
+	sctp_o2o=0;
+	err=0;
 
-	opterr = 0;
-	while((c = getopt(argc, argv, "f:c:d:p:s:t:n:rTS1RvhV")) != -1) {
-		switch(c) {
+	opterr=0;
+	while ((c=getopt(argc,argv, "f:c:d:p:s:t:n:rTS1RvhV"))!=-1){
+		switch(c){
 			case 'f':
-				fname = optarg;
+				fname=optarg;
 				break;
 			case 'v':
 				verbose++;
 				break;
 			case 'd':
-				dst = optarg;
+				dst=optarg;
 				break;
 			case 'p':
-				port = strtol(optarg, &tmp, 10);
-				if((tmp == 0) || (*tmp)) {
+				port=strtol(optarg, &tmp, 10);
+				if ((tmp==0)||(*tmp)){
 					fprintf(stderr, "bad port number: -p %s\n", optarg);
 					goto error;
 				}
 				break;
 			case 'c':
-				count = strtol(optarg, &tmp, 10);
-				if((tmp == 0) || (*tmp)) {
+				count=strtol(optarg, &tmp, 10);
+				if ((tmp==0)||(*tmp)){
 					fprintf(stderr, "bad count: -c %s\n", optarg);
 					goto error;
 				}
 				break;
 			case 's':
-				usec = strtol(optarg, &tmp, 10);
-				if((tmp == 0) || (*tmp)) {
+				usec=strtol(optarg, &tmp, 10);
+				if ((tmp==0)||(*tmp)){
 					fprintf(stderr, "bad count: -c %s\n", optarg);
 					goto error;
 				}
 				break;
 			case 't':
-				throttle = strtol(optarg, &tmp, 10);
-				if((tmp == 0) || (*tmp)) {
+				throttle=strtol(optarg, &tmp, 10);
+				if ((tmp==0)||(*tmp)){
 					fprintf(stderr, "bad count: -c %s\n", optarg);
 					goto error;
 				}
 				break;
 			case 'n':
-				con_no = strtol(optarg, &tmp, 10);
-				if((tmp == 0) || (*tmp) || (con_no < 1)) {
+				con_no=strtol(optarg, &tmp, 10);
+				if ((tmp==0)||(*tmp)||(con_no<1)){
 					fprintf(stderr, "bad count: -c %s\n", optarg);
 					goto error;
 				}
 				break;
 			case 'r':
-				random_sleep = 1;
+				random_sleep=1;
 				break;
 			case 'T':
-				proto = PROTO_TCP;
+				proto=PROTO_TCP;
 				break;
 			case 'S':
 #ifdef USE_SCTP
-				proto = PROTO_SCTP;
+				proto=PROTO_SCTP;
 #else
 				fprintf(stderr, "sctp not supported (recompile with "
 								"-DUSE_SCTP)\n");
@@ -182,10 +177,10 @@ int main(int argc, char **argv)
 #endif /* USE_SCTP */
 				break;
 			case '1':
-				sctp_o2o = 1;
+				sctp_o2o=1;
 				break;
 			case 'R':
-				tcp_rst = 1;
+				tcp_rst=1;
 				break;
 			case 'V':
 				printf("version: %s\n", version);
@@ -197,85 +192,84 @@ int main(int argc, char **argv)
 				exit(0);
 				break;
 			case '?':
-				if(isprint(optopt))
+				if (isprint(optopt))
 					fprintf(stderr, "Unknown option '-%c'\n", optopt);
 				else
 					fprintf(stderr, "Unknown character '\\x%x'\n", optopt);
 				goto error;
 			case ':':
-				fprintf(stderr, "Option '-%c' requires an argument.\n", optopt);
+				fprintf(stderr, "Option '-%c' requires an argument.\n",
+						optopt);
 				goto error;
 				break;
 			default:
-				abort();
+					abort();
 		}
 	}
 
 	/* check if all the required params are present */
-	if(fname == 0) {
+	if (fname==0){
 		fprintf(stderr, "Missing -f file\n");
 		exit(-1);
 	}
-	if(dst == 0) {
+	if (dst==0){
 		fprintf(stderr, "Missing destination (-d ...)\n");
 		exit(-1);
 	}
-	if(port == 0) {
+	if(port==0){
 		fprintf(stderr, "Missing port number (-p port)\n");
 		exit(-1);
-	} else if(port < 0) {
+	}else if(port<0){
 		fprintf(stderr, "Invalid port number (-p %d)\n", port);
 		exit(-1);
 	}
-	if(count == 0) {
+	if(count==0){
 		fprintf(stderr, "Missing packet count (-c number)\n");
 		exit(-1);
-	} else if(count < 0) {
+	}else if(count<0){
 		fprintf(stderr, "Invalid packet count (-c %d)\n", count);
 		exit(-1);
 	}
-	if(proto == PROTO_UDP || (proto == PROTO_SCTP && !sctp_o2o))
-		con_no = 1;
+	if (proto==PROTO_UDP || (proto==PROTO_SCTP && !sctp_o2o)) con_no=1;
 
 	/* ignore sigpipe */
-	if(signal(SIGPIPE, SIG_IGN) == SIG_ERR) {
+	if (signal(SIGPIPE, SIG_IGN)==SIG_ERR){
 		fprintf(stderr, "failed to ignore SIGPIPE: %s\n", strerror(errno));
 		exit(-1);
 	}
 
 	/* open packet file */
-	fd = open(fname, O_RDONLY);
-	if(fd < 0) {
+	fd=open(fname, O_RDONLY);
+	if (fd<0){
 		fprintf(stderr, "ERROR: loading packet-file(%s): %s\n", fname,
 				strerror(errno));
 		goto error;
 	}
-	n = read(fd, buf, BUF_SIZE);
-	if(n < 0) {
+	n=read(fd, buf, BUF_SIZE);
+	if (n<0){
 		fprintf(stderr, "ERROR: reading file(%s): %s\n", fname,
 				strerror(errno));
 		goto error;
 	}
-	if(verbose)
-		printf("read %d bytes from file %s\n", n, fname);
+	if (verbose) printf("read %d bytes from file %s\n", n, fname);
 	close(fd);
 
 	/* resolve destination */
-	he = gethostbyname(dst);
-	if(he == 0) {
+	he=gethostbyname(dst);
+	if (he==0){
 		fprintf(stderr, "ERROR: could not resolve %s\n", dst);
 		goto error;
 	}
 	/* open socket*/
-	addr.sin_family = he->h_addrtype;
-	addr.sin_port = htons(port);
+	addr.sin_family=he->h_addrtype;
+	addr.sin_port=htons(port);
 #ifdef HAVE_SOCKADDR_SA_LEN
-	addr.sin_len = sizeof(struct sockaddr_in);
+	addr.sin_len=sizeof(struct sockaddr_in);
 #endif
 	memcpy(&addr.sin_addr.s_addr, he->h_addr_list[0], he->h_length);
 
-	for(k = 0; k < con_no; k++) {
-		switch(proto) {
+	for (k=0; k<con_no; k++){
+		switch(proto){
 			case PROTO_UDP:
 				sock = socket(he->h_addrtype, SOCK_DGRAM, 0);
 				break;
@@ -285,112 +279,100 @@ int main(int argc, char **argv)
 #ifdef USE_SCTP
 			case PROTO_SCTP:
 				sock = socket(he->h_addrtype,
-						sctp_o2o ? SOCK_STREAM : SOCK_SEQPACKET, IPPROTO_SCTP);
+								sctp_o2o?SOCK_STREAM:SOCK_SEQPACKET,
+								IPPROTO_SCTP);
 				break;
 #endif /* USE_SCTP */
 			default:
 				fprintf(stderr, "BUG: unkown proto %d\n", proto);
 				goto error;
 		}
-		if(sock == -1) {
+		if (sock==-1){
 			fprintf(stderr, "ERROR: socket: %s\n", strerror(errno));
 			goto error;
 		}
-		if(proto == PROTO_TCP) {
-			t = 1;
-			if(setsockopt(sock, IPPROTO_TCP, TCP_NODELAY, &t, sizeof(t)) < 0) {
+		if (proto==PROTO_TCP){
+			t=1;
+			if (setsockopt(sock, IPPROTO_TCP , TCP_NODELAY, &t, sizeof(t))<0){
 				fprintf(stderr, "ERROR: could not disable Nagle: %s\n",
-						strerror(errno));
+								strerror(errno));
 			}
-			if(tcp_rst) {
-				t_linger.l_onoff = 1;
-				t_linger.l_linger = 0;
-				if(setsockopt(sock, SOL_SOCKET, SO_LINGER, &t_linger,
-						   sizeof(t_linger))
-						< 0) {
+			if (tcp_rst){
+				t_linger.l_onoff=1;
+				t_linger.l_linger=0;
+				if (setsockopt(sock, SOL_SOCKET, SO_LINGER, &t_linger,
+									sizeof(t_linger))<0){
 					fprintf(stderr, "ERROR: could not set SO_LINGER: %s\n",
-							strerror(errno));
+									strerror(errno));
 				}
 			}
 		}
 #ifdef USE_SCTP
-		else if(proto == PROTO_SCTP) {
-			t = 1;
-			if(setsockopt(sock, IPPROTO_SCTP, SCTP_NODELAY, &t, sizeof(t))
-					< 0) {
+		else if (proto==PROTO_SCTP){
+			t=1;
+			if (setsockopt(sock, IPPROTO_SCTP, SCTP_NODELAY, &t, sizeof(t))<0){
 				fprintf(stderr, "ERROR: could not disable Nagle: %s\n",
-						strerror(errno));
+								strerror(errno));
 			}
 		}
 #endif /* USE_SCTP */
 
-		if(
+		if (
 #ifdef USE_SCTP
-				(proto != PROTO_SCTP || sctp_o2o) &&
+			(proto!=PROTO_SCTP || sctp_o2o) &&
 #endif /* USE_SCTP */
-				(connect(sock, (struct sockaddr *)&addr,
-						 sizeof(struct sockaddr))
-						!= 0)) {
+			(connect(sock, (struct sockaddr*) &addr,
+					sizeof(struct sockaddr))!=0)){
 			fprintf(stderr, "ERROR: connect: %s\n", strerror(errno));
 			goto error;
 		}
 
 		/* flood loop */
-		t = throttle;
-		for(r = 0; r < count; r++) {
-			if((verbose > 1) && ((r % 1000) == 999)) {
-				putchar('.');
-				fflush(stdout);
-			}
+		t=throttle;
+		for (r=0; r<count; r++){
+			if ((verbose>1)&&((r%1000)==999)){  putchar('.'); fflush(stdout); }
 #ifdef USE_SCTP
-			if(proto == PROTO_SCTP && !sctp_o2o) {
-				if(sctp_sendmsg(sock, buf, n, (struct sockaddr *)&addr,
-						   sizeof(struct sockaddr), 0, SCTP_UNORDERED, 0, 0, 0)
-						== -1) {
+			if (proto==PROTO_SCTP && !sctp_o2o){
+				if (sctp_sendmsg(sock, buf, n,  (struct sockaddr*) &addr,
+									sizeof(struct sockaddr), 0, SCTP_UNORDERED,
+									0, 0, 0)==-1){
 					fprintf(stderr, "Error(%d): send: %s\n", err,
 							strerror(errno));
-					err++;
-					;
+					err++;;
 				}
-			} else
+			}else
 #endif /* USE_SCTP */
 			{
-				if(send(sock, buf, n, 0) == -1) {
+				if (send(sock, buf, n, 0)==-1) {
 					fprintf(stderr, "Error(%d): send: %s\n", err,
 							strerror(errno));
-					err++;
-					;
+					err++;;
 				}
 			}
-			if(usec) {
+			if (usec){
 				t--;
-				if(t == 0) {
-					usleep(random_sleep ? (unsigned long)((double)usec * rand()
-														  / RAND_MAX)
-										: usec);
-					t = throttle;
+				if (t==0){
+					usleep(random_sleep?
+								(unsigned long)((double)usec*rand()/RAND_MAX):usec);
+					t=throttle;
 				}
 			}
 		}
 
 		close(sock);
-		if((verbose) && (k % 1000 == 999)) {
-			putchar('#');
-			fflush(stdout);
-		}
+		if ((verbose) && (k%1000==999)) { putchar('#'); fflush(stdout); }
 	}
-	if(proto == PROTO_TCP || proto == PROTO_SCTP) {
+	if (proto==PROTO_TCP || proto==PROTO_SCTP){
 		printf("\n%d packets sent on %d %s connections (%d on each of them),"
-			   " %d bytes each => total %d bytes\n",
-				count * con_no - err, con_no,
-				(proto == PROTO_TCP) ? "tcp" : "sctp", count, n,
-				(con_no * count - err) * n);
-	} else {
+				" %d bytes each => total %d bytes\n",
+				count*con_no-err, con_no, (proto==PROTO_TCP)?"tcp":"sctp",
+				count, n,
+				(con_no*count-err)*n);
+	}else{
 		printf("\n%d packets sent, %d bytes each => total %d bytes\n",
-				count - err, n, n * (count - err));
+				count-err, n, n*(count-err));
 	}
-	if(err)
-		printf("%d errors\n", err);
+	if (err) printf("%d errors\n", err);
 	exit(0);
 
 error:
