@@ -178,6 +178,9 @@ int fixup_free_ssi(void **param, int param_no);
 int fixup_sii(void **param, int param_no);
 int fixup_free_sii(void **param, int param_no);
 
+int fixup_sis(void **param, int param_no);
+int fixup_free_sis(void **param, int param_no);
+
 int fixup_sssi(void **param, int param_no);
 int fixup_free_sssi(void **param, int param_no);
 
