@@ -25,7 +25,7 @@ MODIFIED:
 		*(r++) = b = ind(mm, y >> RANDSIZL) + x; \
 	}
 
-void isaac(ctx) randctx *ctx;
+void isaac(randctx *ctx)
 {
 	register ub4 a, b, x, y, *m, *mm, *m2, *r, *mend;
 	mm = ctx->randmem;
@@ -78,8 +78,7 @@ void isaac(ctx) randctx *ctx;
 	}
 
 /* if (flag==TRUE), then use the contents of randrsl[] to initialize mm[]. */
-void randinit(ctx, flag) randctx *ctx;
-word flag;
+void randinit(randctx *ctx, word flag)
 {
 	word i;
 	ub4 a, b, c, d, e, f, g, h;
