@@ -154,7 +154,7 @@ void ksr_module_set_flag(unsigned int flag);
 	-127 /**< special rank, the context is the main kamailio
 							  process, but this is guaranteed to be executed
 							  before any process is forked, so it can be used
-							  to setup shared variables that depend on some
+							  to set up shared variables that depend on some
 							  after mod_init available information (e.g.
 							  total number of processes).
 							  @warning child_init(PROC_MAIN) is again called
@@ -310,7 +310,7 @@ typedef struct module_exports
 } module_exports_t;
 
 
-/** kamailio module exports version coverted for core operations */
+/** kamailio module exports version converted for core operations */
 typedef struct ksr_module_exports
 {
 	/**< null terminated module name */
@@ -347,7 +347,7 @@ typedef struct sr_module
 
 extern sr_module_t *modules;				 /**< global module list*/
 extern response_function *mod_response_cbks; /**< response callback array */
-extern int mod_response_cbk_no; /**< size of reponse callbacks array */
+extern int mod_response_cbk_no; /**< size of response callbacks array */
 
 int register_builtin_modules(void);
 int ksr_load_module(char *path, char *opts);
