@@ -30,23 +30,20 @@
 
 int str_append(str *orig, str *suffix, str *dest)
 {
-	if(orig == NULL || suffix == NULL || suffix->len == 0 || dest == NULL)
-	{
+	if(orig == NULL || suffix == NULL || suffix->len == 0 || dest == NULL) {
 		LM_ERR("wrong parameters\n");
 		return -1;
 	}
 	dest->len = orig->len + suffix->len;
-	dest->s = pkg_malloc(sizeof(char)*dest->len);
-	if(dest->s==NULL)
-	{
+	dest->s = pkg_malloc(sizeof(char) * dest->len);
+	if(dest->s == NULL) {
 		PKG_MEM_ERROR;
 		return -1;
 	}
-	if(orig->len>0)
-	{
+	if(orig->len > 0) {
 		memcpy(dest->s, orig->s, orig->len);
 	}
-	memcpy(dest->s+orig->len, suffix->s, suffix->len);
+	memcpy(dest->s + orig->len, suffix->s, suffix->len);
 	return 0;
 }
 
@@ -54,21 +51,21 @@ int str_append(str *orig, str *suffix, str *dest)
 * Find the first occurrence of find in s, where the search is limited to the
 * first slen characters of s.
 */
-char * _strnstr(const char* s, const char* find, size_t slen)
+char *_strnstr(const char *s, const char *find, size_t slen)
 {
 	char c, sc;
 	size_t len;
 
-	if ((c = *find++) != '\0') {
+	if((c = *find++) != '\0') {
 		len = strlen(find);
 		do {
 			do {
-				if (slen-- < 1 || (sc = *s++) == '\0')
+				if(slen-- < 1 || (sc = *s++) == '\0')
 					return (NULL);
-			} while (sc != c);
-			if (len > slen)
+			} while(sc != c);
+			if(len > slen)
 				return (NULL);
-		} while (strncmp(s, find, len) != 0);
+		} while(strncmp(s, find, len) != 0);
 		s--;
 	}
 	return ((char *)s);
@@ -79,23 +76,22 @@ char * _strnstr(const char* s, const char* find, size_t slen)
  * search is limited to the first slen characters of s.
  * Based on FreeBSD strnstr.
  */
-char* _strnistr(const char *s, const char *find, size_t slen)
+char *_strnistr(const char *s, const char *find, size_t slen)
 {
 	char c, sc;
 	size_t len;
 
-	if ((c = *find++) != '\0') {
+	if((c = *find++) != '\0') {
 		len = strlen(find);
 		do {
 			do {
-				if ((sc = *s++) == '\0' || slen-- < 1)
+				if((sc = *s++) == '\0' || slen-- < 1)
 					return (NULL);
-			} while (sc != c);
-			if (len > slen)
+			} while(sc != c);
+			if(len > slen)
 				return (NULL);
-		} while (strncasecmp(s, find, len) != 0);
+		} while(strncasecmp(s, find, len) != 0);
 		s--;
 	}
 	return ((char *)s);
 }
-
