@@ -115,6 +115,10 @@ sr_xavp_t *xavp_get_child_with_ival(str *rname, str *cname);
 sr_xavp_t *xavp_get_child_with_sval(str *rname, str *cname);
 int xavp_serialize_fields(str *rname, char *obuf, int olen);
 
+#define XAVP_PRINT_SCPR 1 /* semicolon prefix */
+#define XAVP_PRINT_QVAL 2 /* quote string param values */
+int xavp_serialize_fields_style(str *rname, int mode, char *obuf, int olen);
+
 int xavp_set_child_ival(str *rname, str *cname, long ival);
 int xavp_set_child_sval(str *rname, str *cname, str *sval);
 
