@@ -45,26 +45,29 @@ struct acc_extra *parse_acc_extra(char *extra);
 
 struct acc_extra *parse_acc_leg(char *extra);
 
-void destroy_extras( struct acc_extra *extra);
+void destroy_extras(struct acc_extra *extra);
 
-int extra2strar( struct acc_extra *extra, struct sip_msg *rq,
-		 str *val_arr, int *int_arr, char *type_arr);
+int extra2strar(struct acc_extra *extra, struct sip_msg *rq, str *val_arr,
+		int *int_arr, char *type_arr);
 
-int extra2strar_dlg_only(struct acc_extra *extra, struct dlg_cell* dlg,
-		str *val_arr, int *int_arr, char *type_arr, const struct dlg_binds* p_dlgb);
+int extra2strar_dlg_only(struct acc_extra *extra, struct dlg_cell *dlg,
+		str *val_arr, int *int_arr, char *type_arr,
+		const struct dlg_binds *p_dlgb);
 
-int legs2strar( struct acc_extra *legs, struct sip_msg *rq, str *val_arr,
+int legs2strar(struct acc_extra *legs, struct sip_msg *rq, str *val_arr,
 		int *int_arr, char *type_arr, int start);
 
-int extra2int( struct acc_extra *extra, int *attrs );
+int extra2int(struct acc_extra *extra, int *attrs);
 
-static inline void free_strar_mem( char* type_arr, str* alloc_arr, int dim_arr, int dim_ext){
+static inline void free_strar_mem(
+		char *type_arr, str *alloc_arr, int dim_arr, int dim_ext)
+{
 	int i = 0;
-	for ( i = 0; i < dim_arr; i ++ ) {
-		if (( TYPE_NULL !=  type_arr[i] ) && (  NULL != alloc_arr[i].s)) {
+	for(i = 0; i < dim_arr; i++) {
+		if((TYPE_NULL != type_arr[i]) && (NULL != alloc_arr[i].s)) {
 			LM_DBG("Freeing memory, type is %d, message_index %d, index i %d\n",
 					type_arr[i], dim_ext - dim_arr, i);
-			pkg_free( alloc_arr[i].s) ;
+			pkg_free(alloc_arr[i].s);
 			alloc_arr[i].s = NULL;
 		}
 	}
@@ -74,4 +77,3 @@ int acc_extra_arrays_alloc(void);
 void acc_extra_arrays_free(void);
 
 #endif
-
