@@ -4,14 +4,16 @@
 #include "duktape.h"
 
 #if defined(__cplusplus)
-extern "C" {
+extern "C"
+{
 #endif
 
-	extern duk_ret_t duk_module_node_peval_main(duk_context *ctx, const char *path);
+	extern duk_ret_t duk_module_node_peval_main(
+			duk_context *ctx, const char *path);
 	extern void duk_module_node_init(duk_context *ctx);
 
 #if defined(__cplusplus)
 }
-#endif  /* end 'extern "C"' wrapper */
+#endif /* end 'extern "C"' wrapper */
 
-#endif  /* DUK_MODULE_NODE_H_INCLUDED */
\ No newline at end of file
+#endif /* DUK_MODULE_NODE_H_INCLUDED */
\ No newline at end of file
