@@ -26,10 +26,8 @@
 #include "../../core/str.h"
 
 int authx_xkey_add_params(str *sparam);
-int auth_xkeys_add(sip_msg_t* msg, str *hdr, str *key,
-		str *alg, str *data);
-int auth_xkeys_check(sip_msg_t* msg, str *hdr, str *key,
-		str *alg, str *data);
+int auth_xkeys_add(sip_msg_t *msg, str *hdr, str *key, str *alg, str *data);
+int auth_xkeys_check(sip_msg_t *msg, str *hdr, str *key, str *alg, str *data);
 int auth_xkeys_init_rpc(void);
 
 #endif
