@@ -4,6 +4,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -74,6 +76,7 @@ data_t _data;
 struct dlg_binds _dlgbinds;
 
 static int cnxcc_set_max_credit_fixup(void **param, int param_no);
+static int cnxcc_set_max_credit_fixup_free(void **param, int param_no);
 
 /*
  *  module core functions
@@ -153,7 +156,7 @@ static pv_export_t mod_pvs[] = {
 
 static cmd_export_t cmds[] = {
 	{"cnxcc_set_max_credit", (cmd_function) __set_max_credit, 6,
-		cnxcc_set_max_credit_fixup, NULL, ANY_ROUTE},
+		cnxcc_set_max_credit_fixup, cnxcc_set_max_credit_fixup_free, ANY_ROUTE},
 	{"cnxcc_set_max_time", (cmd_function) __set_max_time, 2,
 		fixup_spve_igp, fixup_free_spve_igp, ANY_ROUTE},
 	{"cnxcc_update_max_time", (cmd_function) __update_max_time, 2,
@@ -168,8 +171,7 @@ static cmd_export_t cmds[] = {
 };
 
 static param_export_t params[] = {
-	{"dlg_flag", INT_PARAM,	&_data.ctrl_flag },
-	{"credit_check_period", INT_PARAM,	&_data.check_period },
+	{"credit_check_period", PARAM_INT,	&_data.check_period },
 	{"redis", PARAM_STR, &_data.redis_cnn_str },
 	{ 0, 0, 0 }
 };
@@ -239,6 +241,23 @@ static int cnxcc_set_max_credit_fixup(void **param, int param_no)
 	}
 }
 
+static int cnxcc_set_max_credit_fixup_free(void **param, int param_no)
+{
+	switch(param_no) {
+		case 1:
+		case 2:
+		case 3:
+		case 4:
+			return fixup_free_spve_all(param, param_no);
+		case 5:
+		case 6:
+			return fixup_free_igp_all(param, param_no);
+		default:
+			LM_ERR("unexpected parameter number: %d\n", param_no);
+			return E_CFG;
+	}
+}
+
 static int __mod_init(void)
 {
 	int len;
@@ -446,11 +465,6 @@ static void __dialog_created_callback(
 		return;
 	}
 
-	if(isflagset(msg, _data.ctrl_flag) == -1) {
-		LM_DBG("Flag is not set for this message. Ignoring\n");
-		return;
-	}
-
 	LM_DBG("Dialog created for CID [%.*s]\n", cell->callid.len, cell->callid.s);
 
 	_dlgbinds.register_dlgcb(
@@ -1489,14 +1503,6 @@ static int __add_call_by_cid(str *cid, call_t *call, credit_type_t type)
 	return 0;
 }
 
-static inline void set_ctrl_flag(struct sip_msg *msg)
-{
-	if(_data.ctrl_flag != -1) {
-		LM_DBG("Flag set!\n");
-		setflag(msg, _data.ctrl_flag);
-	}
-}
-
 static inline int get_pv_value(
 		struct sip_msg *msg, pv_spec_t *spec, pv_value_t *value)
 {
@@ -1567,8 +1573,6 @@ static int ki_set_max_credit(sip_msg_t *msg, str *sclient, str *scredit,
 			sclient->len, sclient->s, credit, connect_cost, cost_per_second,
 			initp, finishp, msg->callid->body.len, msg->callid->body.s);
 
-	set_ctrl_flag(msg);
-
 	if((credit_data = __get_or_create_credit_data_entry(sclient, CREDIT_MONEY))
 			== NULL) {
 		LM_ERR("Error retrieving credit data from shared memory for client "
@@ -1755,8 +1759,6 @@ static int ki_set_max_channels(sip_msg_t *msg, str *sclient, int max_chan)
 		return -1;
 	}
 
-	set_ctrl_flag(msg);
-
 	if(max_chan <= 0) {
 		LM_ERR("[%.*s] MAX_CHAN cannot be less than or equal to zero: %d\n",
 				msg->callid->body.len, msg->callid->body.s, max_chan);
@@ -1849,8 +1851,6 @@ static int ki_set_max_time(sip_msg_t *msg, str *sclient, int max_secs)
 		return -1;
 	}
 
-	set_ctrl_flag(msg);
-
 	if(max_secs <= 0) {
 		LM_ERR("[%.*s] MAXSECS cannot be less than or equal to zero: %d\n",
 				msg->callid->body.len, msg->callid->body.s, max_secs);
@@ -1922,8 +1922,6 @@ static int ki_update_max_time(sip_msg_t *msg, str *sclient, int secs)
 	double update_fraction = secs;
 	call_t *call = NULL, *tmp_call = NULL;
 
-	set_ctrl_flag(msg);
-
 	if(parse_headers(msg, HDR_CALLID_F, 0) != 0) {
 		LM_ERR("Error parsing Call-ID");
 		return -1;
