@@ -4,6 +4,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -1259,7 +1261,7 @@ err:
 static int rpc_struct_printf(struct text_chunk *c, char *name, char *fmt, ...)
 {
 	int n, buf_size;
-	char *buf;
+	char *buf = NULL;
 	char *buf0;
 	va_list ap;
 	str s, nm;
@@ -1288,7 +1290,7 @@ static int rpc_struct_printf(struct text_chunk *c, char *name, char *fmt, ...)
 					&nm, 1); /* Escape all characters, including : and , */
 			if(!m) {
 				rpc_fault(ctx, 500, "Internal Server Error");
-				goto err;
+				goto error;
 			}
 
 			s.s = buf;
@@ -1298,7 +1300,7 @@ static int rpc_struct_printf(struct text_chunk *c, char *name, char *fmt, ...)
 				rpc_fault(ctx, 500, "Internal Server Error");
 				free_chunk(m);
 				ERR("Error while creating text_chunk structure");
-				goto err;
+				goto error;
 			}
 
 			l->flags |= CHUNK_MEMBER_VALUE;
@@ -1312,6 +1314,7 @@ static int rpc_struct_printf(struct text_chunk *c, char *name, char *fmt, ...)
 			c->next = m;
 			if(c == ctx->last)
 				ctx->last = m;
+			ctl_free(buf);
 			return 0;
 		}
 		/* Else try again with more space. */
@@ -1323,12 +1326,12 @@ static int rpc_struct_printf(struct text_chunk *c, char *name, char *fmt, ...)
 		if((buf0 = ctl_realloc(buf, buf_size)) == 0) {
 			rpc_fault(ctx, 500, "Internal Server Error (No memory left)");
 			ERR("No memory left\n");
-			goto err;
+			goto error;
 		}
 		buf = buf0;
 	}
-	return 0;
-err:
+
+error:
 	if(buf)
 		ctl_free(buf);
 	return -1;
