@@ -5,6 +5,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -115,14 +117,14 @@ static cmd_export_t cmds[] = {
 };
 
 static param_export_t params[] = {
-	{"num_workers", INT_PARAM, &dmq_num_workers},
-	{"ping_interval", INT_PARAM, &dmq_ping_interval},
+	{"num_workers", PARAM_INT, &dmq_num_workers},
+	{"ping_interval", PARAM_INT, &dmq_ping_interval},
 	{"server_address", PARAM_STR, &dmq_server_address},
 	{"server_socket", PARAM_STR, &dmq_server_socket},
-	{"notification_address", PARAM_STR|USE_FUNC_PARAM, dmq_add_notification_address},
+	{"notification_address", PARAM_STR|PARAM_USE_FUNC, dmq_add_notification_address},
 	{"notification_channel", PARAM_STR, &dmq_notification_channel},
-	{"multi_notify", INT_PARAM, &dmq_multi_notify},
-	{"worker_usleep", INT_PARAM, &dmq_worker_usleep},
+	{"multi_notify", PARAM_INT, &dmq_multi_notify},
+	{"worker_usleep", PARAM_INT, &dmq_worker_usleep},
 	{0, 0, 0}
 };
 
