@@ -5,7 +5,7 @@
  *
  * The initial version of this code was written by Dragos Vingarzan
  * (dragos(dot)vingarzan(at)fokus(dot)fraunhofer(dot)de and the
- * Fruanhofer Institute. It was and still is maintained in a separate
+ * Fraunhofer FOKUS Institute. It was and still is maintained in a separate
  * branch of the original SER. We are therefore migrating it to
  * Kamailio/SR and look forward to maintaining it from here on out.
  * 2011/2012 Smile Communications, Pty. Ltd.
@@ -15,7 +15,7 @@
  * effort to add full IMS support to Kamailio/SR using a new and
  * improved architecture
  *
- * NB: Alot of this code was originally part of OpenIMSCore,
+ * NB: A lot of this code was originally part of OpenIMSCore,
  * FhG Fokus.
  * Copyright (C) 2004-2006 FhG Fokus
  * Thanks for great work! This is an effort to
@@ -26,6 +26,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -83,9 +85,15 @@ int publish_reginfo = 0;
 int subscribe_to_reginfo = 0;
 int subscription_expires = 3600;
 int ignore_reg_state = 0;
-/**!< ignore port checks between received port on message and registration received port.
+/** ignore port checks between received port on message and registration received port.
  * this is useful for example if you register with UDP but possibly send invite over TCP (message too big) */
 int ignore_contact_rxport_check = 0;
+/** ignore proto checks between the one that the message was received over and registration one.
+ * Since in IMS is registering the IP:port of the UE with IPsec for any transport, why was this even needed? Hence
+ * setting to 1 as default.*/
+int ignore_contact_rxproto_check = 1;
+/** If set, this uses the bottom Via for identification of UE, always, on both requests and responses, over Contact. */
+int trust_bottom_via = 0;
 
 time_t time_now;
 
@@ -102,11 +110,11 @@ int reginfo_queue_size_threshold =
 
 
 char *rcv_avp_param = 0;
-unsigned short rcv_avp_type = 0;
-int_str rcv_avp_name;
+avp_flags_t rcv_avp_type = 0;
+avp_name_t rcv_avp_name;
 
 ims_registrar_pcscf_params_t _imsregp_params = {
-	.delete_delay = 0
+		.delete_delay = 0,
 };
 
 // static str orig_prefix = {"sip:orig@",9};
@@ -150,76 +158,68 @@ inline void pcscf_act_time()
 	time_now = time(0);
 }
 
+/* clang-format off */
 /*! \brief
  * Exported functions
  */
 static cmd_export_t cmds[] = {
 		{"pcscf_save", (cmd_function)w_save, 1, save_fixup2, 0, ONREPLY_ROUTE},
-		{"pcscf_save_pending", (cmd_function)w_save_pending, 1, save_fixup2, 0,
-				REQUEST_ROUTE},
-		{"pcscf_follows_service_routes", (cmd_function)w_follows_service_routes,
-				1, save_fixup2, 0, REQUEST_ROUTE},
-		{"pcscf_force_service_routes", (cmd_function)w_force_service_routes, 1,
-				save_fixup2, 0, REQUEST_ROUTE},
-		{"pcscf_is_registered", (cmd_function)w_is_registered, 1, save_fixup2,
-				0, REQUEST_ROUTE | ONREPLY_ROUTE},
-		{"pcscf_assert_identity", (cmd_function)w_assert_identity, 2,
-				assert_identity_fixup, 0, REQUEST_ROUTE},
-		{"pcscf_assert_called_identity", (cmd_function)w_assert_called_identity,
-				1, assert_identity_fixup, 0, ONREPLY_ROUTE},
-		{"reginfo_handle_notify", (cmd_function)w_reginfo_handle_notify, 1,
-				domain_fixup, 0, REQUEST_ROUTE},
-		{"pcscf_unregister", (cmd_function)w_unregister, 4, unregister_fixup, 0,
-				ANY_ROUTE},
-		{0, 0, 0, 0, 0, 0}};
-
+		{"pcscf_save_pending", (cmd_function)w_save_pending, 1, save_fixup2, 0, REQUEST_ROUTE},
+		{"pcscf_follows_service_routes", (cmd_function)w_follows_service_routes, 1, save_fixup2, 0, REQUEST_ROUTE},
+		{"pcscf_force_service_routes", (cmd_function)w_force_service_routes, 1, save_fixup2, 0, REQUEST_ROUTE},
+		{"pcscf_is_registered", (cmd_function)w_is_registered, 1, save_fixup2, 0, REQUEST_ROUTE | ONREPLY_ROUTE},
+		{"pcscf_assert_identity", (cmd_function)w_assert_identity, 2, assert_identity_fixup, 0, REQUEST_ROUTE},
+		{"pcscf_assert_called_identity", (cmd_function)w_assert_called_identity, 1, assert_identity_fixup, 0, ONREPLY_ROUTE},
+		{"reginfo_handle_notify", (cmd_function)w_reginfo_handle_notify, 1, domain_fixup, 0, REQUEST_ROUTE},
+		{"pcscf_unregister", (cmd_function)w_unregister, 4, unregister_fixup, 0, ANY_ROUTE},
+		{0, 0, 0, 0, 0, 0}
+};
 
 /*! \brief
  * Exported parameters
  */
 static param_export_t params[] = {{"pcscf_uri", PARAM_STR, &pcscf_uri},
-		{"pending_reg_expires", INT_PARAM, &pending_reg_expires},
-		{"received_avp", PARAM_STR, &rcv_avp_param},
-		{"is_registered_fallback2ip", INT_PARAM, &is_registered_fallback2ip},
-		{"publish_reginfo", INT_PARAM, &publish_reginfo},
-		{"subscribe_to_reginfo", INT_PARAM, &subscribe_to_reginfo},
-		{"subscription_expires", INT_PARAM, &subscription_expires},
-		{"ignore_contact_rxport_check", INT_PARAM,
-				&ignore_contact_rxport_check},
-		{"ignore_reg_state", INT_PARAM, &ignore_reg_state},
-		{"force_icscf_uri", PARAM_STR, &force_icscf_uri},
-		{"reginfo_queue_size_threshold", INT_PARAM,
-				&reginfo_queue_size_threshold},
-		{"delete_delay", PARAM_INT, &_imsregp_params.delete_delay},
-		//	{"store_profile_dereg",	INT_PARAM, &store_data_on_dereg},
-		{0, 0, 0}};
+	{"pending_reg_expires", PARAM_INT, &pending_reg_expires},
+	{"received_avp", PARAM_STR, &rcv_avp_param},
+	{"is_registered_fallback2ip", PARAM_INT, &is_registered_fallback2ip},
+	{"publish_reginfo", PARAM_INT, &publish_reginfo},
+	{"subscribe_to_reginfo", PARAM_INT, &subscribe_to_reginfo},
+	{"subscription_expires", PARAM_INT, &subscription_expires},
+	{"ignore_contact_rxport_check", PARAM_INT, &ignore_contact_rxport_check},
+	{"ignore_contact_rxproto_check", PARAM_INT, &ignore_contact_rxproto_check},
+	{"ignore_reg_state", PARAM_INT, &ignore_reg_state},
+	{"force_icscf_uri", PARAM_STR, &force_icscf_uri},
+	{"reginfo_queue_size_threshold", PARAM_INT, &reginfo_queue_size_threshold},
+	{"delete_delay", PARAM_INT, &_imsregp_params.delete_delay},
+	{"trust_bottom_via", PARAM_INT, &trust_bottom_via},
+	//	{"store_profile_dereg",	PARAM_INT, &store_data_on_dereg},
+	{0, 0, 0}
+};
 
 
 static pv_export_t mod_pvs[] = {
-		{{"pcscf_asserted_identity",
-				 (sizeof("pcscf_asserted_identity")
-						 - 1)}, /* The first identity of the contact. */
-				PVT_OTHER, pv_get_asserted_identity_f, 0, 0, 0, 0, 0},
-		{{"pcscf_registration_contact",
-				 (sizeof("pcscf_registration_contact")
-						 - 1)}, /* The contact used during REGISTER */
-				PVT_OTHER, pv_get_registration_contact_f, 0, 0, 0, 0, 0},
-		{{0, 0}, 0, 0, 0, 0, 0, 0, 0}};
+	{{"pcscf_asserted_identity", (sizeof("pcscf_asserted_identity") - 1)}, /* The first identity of the contact. */
+			PVT_OTHER, pv_get_asserted_identity_f, 0, 0, 0, 0, 0},
+	{{"pcscf_registration_contact", (sizeof("pcscf_registration_contact") - 1)}, /* The contact used during REGISTER */
+			PVT_OTHER, pv_get_registration_contact_f, 0, 0, 0, 0, 0},
+	{{0, 0}, 0, 0, 0, 0, 0, 0, 0}
+};
 
 /*! \brief
  * Module exports structure
  */
 struct module_exports exports = {
-		"ims_registrar_pcscf", DEFAULT_DLFLAGS, /* dlopen flags */
-		cmds,									/* Exported functions */
-		params,									/* Exported parameters */
-		0,										/* exported RPC methods */
-		mod_pvs,								/* exported pseudo-variables */
-		0,										/* response handling function */
-		mod_init,	/* module initialization function */
-		child_init, /* Per-child init function */
-		mod_destroy /* destroy function */
+	"ims_registrar_pcscf", DEFAULT_DLFLAGS, /* dlopen flags */
+	cmds,									/* Exported functions */
+	params,									/* Exported parameters */
+	0,										/* exported RPC methods */
+	mod_pvs,								/* exported pseudo-variables */
+	0,										/* response handling function */
+	mod_init,	/* module initialization function */
+	child_init, /* Per-child init function */
+	mod_destroy /* destroy function */
 };
+/* clang-format on */
 
 int fix_parameters()
 {
@@ -298,15 +298,14 @@ static int mod_init(void)
 	bind_ipsec_pcscf =
 			(bind_ipsec_pcscf_t)find_export("bind_ims_ipsec_pcscf", 1, 0);
 	if(!bind_ipsec_pcscf) {
-		LM_ERR("can't bind ims_ipsec_pcscf\n");
-		return -1;
+		LM_WARN("can't bind ims_ipsec_pcscf - will start without\n");
+	} else {
+		if(bind_ipsec_pcscf(&ipsec_pcscf) < 0) {
+			return -1;
+		}
+		LM_INFO("Successfully bound to PCSCF IPSEC module\n");
 	}
 
-	if(bind_ipsec_pcscf(&ipsec_pcscf) < 0) {
-		return -1;
-	}
-	LM_INFO("Successfully bound to PCSCF IPSEC module\n");
-
 	if(subscribe_to_reginfo == 1) {
 		/* Bind to PUA: */
 		bind_pua = (bind_pua_t)find_export("bind_pua", 1, 0);
