@@ -24,13 +24,47 @@
 #define _IPOPS_PV_H_
 
 #include "../../core/pvar.h"
+#define PV_DNS_ADDR 64
+#define PV_DNS_RECS 32
+#define SR_DNS_PVIDX 1
+#define SR_DNS_HOSTNAME_SIZE 256
+typedef struct _sr_dns_record
+{
+	int type;
+	char addr[PV_DNS_ADDR];
+} sr_dns_record_t;
+
+typedef struct _sr_dns_item
+{
+	str name;
+	unsigned int hashid;
+	char hostname[SR_DNS_HOSTNAME_SIZE];
+	int count;
+	int ipv4;
+	int ipv6;
+	sr_dns_record_t r[PV_DNS_RECS];
+	struct _sr_dns_item *next;
+} sr_dns_item_t;
+
+typedef struct _dns_pv
+{
+	sr_dns_item_t *item;
+	int type;
+	int flags;
+	pv_spec_t *pidx;
+	int nidx;
+} dns_pv_t;
 
 int pv_parse_dns_name(pv_spec_t *sp, str *in);
 int pv_get_dns(sip_msg_t *msg, pv_param_t *param, pv_value_t *res);
 
+int pv_parse_ptr_name(pv_spec_t *sp, str *in);
+int pv_get_ptr(sip_msg_t *msg, pv_param_t *param, pv_value_t *res);
+
 int dns_init_pv(char *path);
 void dns_destroy_pv(void);
 int dns_update_pv(str *tomatch, str *name);
+int ptr_update_pv(str *tomatch, str *name);
 
 int pv_parse_hn_name(pv_spec_p sp, str *in);
 int pv_get_hn(struct sip_msg *msg, pv_param_t *param, pv_value_t *res);
