@@ -5,6 +5,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -150,12 +152,14 @@ static cmd_export_t cmds[] = {
 				fixup_kz_amqp_free, ANY_ROUTE},
 		{"kazoo_publish", (cmd_function)kz_amqp_publish_ex, 4, fixup_kz_amqp,
 				fixup_kz_amqp_free, ANY_ROUTE},
-		{"kazoo_query", (cmd_function)kz_amqp_query, 4, fixup_kz_amqp,
+
+		{"kazoo_query", (cmd_function)kz_amqp_query_3, 3, fixup_kz_amqp,
 				fixup_kz_amqp_free, ANY_ROUTE},
-		{"kazoo_query", (cmd_function)kz_amqp_query, 5, fixup_kz_amqp,
+		{"kazoo_query", (cmd_function)kz_amqp_query_4, 4, fixup_kz_amqp,
 				fixup_kz_amqp_free, ANY_ROUTE},
-		{"kazoo_query", (cmd_function)kz_amqp_query_ex, 3, fixup_kz_amqp,
+		{"kazoo_query", (cmd_function)kz_amqp_query_5, 5, fixup_kz_amqp,
 				fixup_kz_amqp_free, ANY_ROUTE},
+
 		{"kazoo_pua_publish", (cmd_function)kz_pua_publish, 1, 0, 0, ANY_ROUTE},
 		{"kazoo_pua_publish_mwi", (cmd_function)kz_pua_publish_mwi, 1, 0, 0,
 				ANY_ROUTE},
@@ -168,8 +172,6 @@ static cmd_export_t cmds[] = {
 				fixup_kz_amqp4_free, ANY_ROUTE},
 		{"kazoo_subscribe", (cmd_function)kz_amqp_subscribe_simple, 4,
 				fixup_kz_amqp4, fixup_kz_amqp4_free, ANY_ROUTE},
-
-
 		{"kazoo_json", (cmd_function)kz_json_get_field, 3, fixup_kz_json,
 				fixup_kz_json_free, ANY_ROUTE},
 		{"kazoo_json_keys", (cmd_function)kz_json_get_keys, 3, fixup_kz_json,
@@ -190,53 +192,53 @@ static cmd_export_t cmds[] = {
 
 static param_export_t params[] = {
 		{"node_hostname", PARAM_STR, &dbk_node_hostname},
-		{"amqp_connection", PARAM_STRING | USE_FUNC_PARAM,
+		{"amqp_connection", PARAM_STRING | PARAM_USE_FUNC,
 				(void *)kz_amqp_add_connection},
-		{"amqp_max_channels", INT_PARAM, &dbk_channels},
-		{"amqp_timer_process_interval", INT_PARAM, &kz_timer_ms},
-		{"amqp_consumer_ack_timeout_micro", INT_PARAM, &kz_ack_tv.tv_usec},
-		{"amqp_consumer_ack_timeout_sec", INT_PARAM, &kz_ack_tv.tv_sec},
-		{"amqp_interprocess_timeout_micro", INT_PARAM, &kz_sock_tv.tv_usec},
-		{"amqp_interprocess_timeout_sec", INT_PARAM, &kz_sock_tv.tv_sec},
-		{"amqp_waitframe_timeout_micro", INT_PARAM, &kz_amqp_tv.tv_usec},
-		{"amqp_waitframe_timeout_sec", INT_PARAM, &kz_amqp_tv.tv_sec},
-		{"amqp_consumer_processes", INT_PARAM, &dbk_consumer_processes},
-		{"amqp_consumer_workers", INT_PARAM, &dbk_consumer_workers},
+		{"amqp_max_channels", PARAM_INT, &dbk_channels},
+		{"amqp_timer_process_interval", PARAM_INT, &kz_timer_ms},
+		{"amqp_consumer_ack_timeout_micro", PARAM_INT, &kz_ack_tv.tv_usec},
+		{"amqp_consumer_ack_timeout_sec", PARAM_INT, &kz_ack_tv.tv_sec},
+		{"amqp_interprocess_timeout_micro", PARAM_INT, &kz_sock_tv.tv_usec},
+		{"amqp_interprocess_timeout_sec", PARAM_INT, &kz_sock_tv.tv_sec},
+		{"amqp_waitframe_timeout_micro", PARAM_INT, &kz_amqp_tv.tv_usec},
+		{"amqp_waitframe_timeout_sec", PARAM_INT, &kz_amqp_tv.tv_sec},
+		{"amqp_consumer_processes", PARAM_INT, &dbk_consumer_processes},
+		{"amqp_consumer_workers", PARAM_INT, &dbk_consumer_workers},
 		{"amqp_consumer_event_key", PARAM_STR, &dbk_consumer_event_key},
 		{"amqp_consumer_event_subkey", PARAM_STR, &dbk_consumer_event_subkey},
-		{"amqp_query_timeout_micro", INT_PARAM, &kz_qtimeout_tv.tv_usec},
-		{"amqp_query_timeout_sec", INT_PARAM, &kz_qtimeout_tv.tv_sec},
-		{"amqp_internal_loop_count", INT_PARAM, &dbk_internal_loop_count},
-		{"amqp_consumer_loop_count", INT_PARAM, &dbk_consumer_loop_count},
-		{"amqp_consumer_ack_loop_count", INT_PARAM,
+		{"amqp_query_timeout_micro", PARAM_INT, &kz_qtimeout_tv.tv_usec},
+		{"amqp_query_timeout_sec", PARAM_INT, &kz_qtimeout_tv.tv_sec},
+		{"amqp_internal_loop_count", PARAM_INT, &dbk_internal_loop_count},
+		{"amqp_consumer_loop_count", PARAM_INT, &dbk_consumer_loop_count},
+		{"amqp_consumer_ack_loop_count", PARAM_INT,
 				&dbk_consumer_ack_loop_count},
-		{"pua_include_entity", INT_PARAM, &dbk_include_entity},
-		{"presence_use_full_entity", INT_PARAM, &dbk_use_full_entity},
+		{"pua_include_entity", PARAM_INT, &dbk_include_entity},
+		{"presence_use_full_entity", PARAM_INT, &dbk_use_full_entity},
 		{"presentity_table", PARAM_STR, &kz_presentity_table},
 		{"db_url", PARAM_STR, &kz_db_url},
-		{"pua_mode", INT_PARAM, &dbk_pua_mode},
-		{"single_consumer_on_reconnect", INT_PARAM,
+		{"pua_mode", PARAM_INT, &dbk_pua_mode},
+		{"single_consumer_on_reconnect", PARAM_INT,
 				&dbk_single_consumer_on_reconnect},
-		{"consume_messages_on_reconnect", INT_PARAM,
+		{"consume_messages_on_reconnect", PARAM_INT,
 				&dbk_consume_messages_on_reconnect},
 		{"amqp_query_timeout_avp", PARAM_STR, &kz_query_timeout_avp},
 		{"json_escape_char", PARAM_STR, &kz_json_escape_str},
 		{"app_name", PARAM_STR, &kz_app_name},
-		{"use_federated_exchange", INT_PARAM, &dbk_use_federated_exchange},
+		{"use_federated_exchange", PARAM_INT, &dbk_use_federated_exchange},
 		{"federated_exchange", PARAM_STR, &dbk_federated_exchange},
-		{"amqp_heartbeats", INT_PARAM, &dbk_use_hearbeats},
+		{"amqp_heartbeats", PARAM_INT, &dbk_use_hearbeats},
 		{"amqp_primary_zone", PARAM_STR, &dbk_primary_zone_name},
-		{"amqp_command_hashtable_size", INT_PARAM, &dbk_command_table_size},
+		{"amqp_command_hashtable_size", PARAM_INT, &dbk_command_table_size},
 		{"amqp_result_avp", PARAM_STR, &kz_query_result_avp},
 		{"amqps_ca_cert", PARAM_STR, &kz_amqps_ca_cert},
 		{"amqps_cert", PARAM_STR, &kz_amqps_cert},
 		{"amqps_key", PARAM_STR, &kz_amqps_key},
-		{"amqps_verify_peer", INT_PARAM, &kz_amqps_verify_peer},
-		{"amqps_verify_hostname", INT_PARAM, &kz_amqps_verify_hostname},
-		{"pua_lock_type", INT_PARAM, &kz_pua_lock_type},
-		{"amqp_connect_timeout_micro", INT_PARAM,
+		{"amqps_verify_peer", PARAM_INT, &kz_amqps_verify_peer},
+		{"amqps_verify_hostname", PARAM_INT, &kz_amqps_verify_hostname},
+		{"pua_lock_type", PARAM_INT, &kz_pua_lock_type},
+		{"amqp_connect_timeout_micro", PARAM_INT,
 				&kz_amqp_connect_timeout_tv.tv_usec},
-		{"amqp_connect_timeout_sec", INT_PARAM,
+		{"amqp_connect_timeout_sec", PARAM_INT,
 				&kz_amqp_connect_timeout_tv.tv_sec},
 		{"event_callback", PARAM_STR, &kazoo_event_callback}, {0, 0, 0}};
 
