@@ -19,16 +19,17 @@
  *
  */
 
-		       
+
 #ifndef _MQUEUE_EXT_API_H_
 #define _MQUEUE_EXT_API_H_
 
-typedef int (*mq_add_f)(str*, str*, str*);
-typedef struct mq_api {
+typedef int (*mq_add_f)(str *, str *, str *);
+typedef struct mq_api
+{
 	mq_add_f add;
 } mq_api_t;
 
-typedef int (*bind_mq_f)(mq_api_t* api);
+typedef int (*bind_mq_f)(mq_api_t *api);
 
 static inline int load_mq_api(mq_api_t *api)
 {
@@ -39,8 +40,7 @@ static inline int load_mq_api(mq_api_t *api)
 		LM_ERR("cannot find bind_mq\n");
 		return -1;
 	}
-	if(bindmq(api)<0)
-	{
+	if(bindmq(api) < 0) {
 		LM_ERR("cannot bind mq api\n");
 		return -1;
 	}
