@@ -58,9 +58,9 @@ static pv_export_t mod_pvs[] = {
 
 static cmd_export_t cmds[]={
 	{"phonenum_match", (cmd_function)w_phonenum_match, 2, fixup_spve_spve,
-		0, ANY_ROUTE},
+		fixup_free_spve_spve, ANY_ROUTE},
 	{"phonenum_match_cn", (cmd_function)w_phonenum_match_cn, 3, fixup_spve_all,
-		0, ANY_ROUTE},
+		fixup_free_spve_all, ANY_ROUTE},
 	{0, 0, 0, 0, 0, 0}
 };
 
@@ -196,6 +196,11 @@ static sr_kemi_t sr_kemi_phonenum_exports[] = {
 		{ SR_KEMIP_STR, SR_KEMIP_STR, SR_KEMIP_NONE,
 			SR_KEMIP_NONE, SR_KEMIP_NONE, SR_KEMIP_NONE }
 	},
+	{ str_init("phonenum"), str_init("match_cn"),
+		SR_KEMIP_INT, phonenum_match_cn,
+		{ SR_KEMIP_STR, SR_KEMIP_STR, SR_KEMIP_STR,
+			SR_KEMIP_NONE, SR_KEMIP_NONE, SR_KEMIP_NONE }
+	},
 
 	{ {0, 0}, {0, 0}, 0, NULL, { 0, 0, 0, 0, 0, 0 } }
 };
