@@ -7,6 +7,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -290,7 +292,7 @@ static int w_pvh_remove_header_param(struct sip_msg *msg, char *p1, char *p2)
 }
 
 /* clang-format off */
-static cmd_export_t cmds[] = {
+static cmd_export_t mod_cmds[] = {
 	{"pvh_collect_headers", (cmd_function)w_pvh_collect_headers, 0, 0, 0,
 			ANY_ROUTE},
 	{"pvh_apply_headers", (cmd_function)w_pvh_apply_headers, 0, 0, 0,
@@ -346,7 +348,7 @@ static pv_export_t mod_pvs[] = {
 	{{0, 0}, 0, 0, 0, 0, 0, 0, 0}
 };
 
-static param_export_t params[] = {
+static param_export_t mod_params[] = {
 	{"xavi_name", PARAM_STR, &_pvh_params.xavi_name},
 	{"header_value_size", PARAM_INT, &_pvh_params.hdr_value_size},
 	{"header_collect_flag", PARAM_INT, &_pvh_params.flags[PVH_HDRS_COLLECTED]},
@@ -358,16 +360,16 @@ static param_export_t params[] = {
 };
 
 struct module_exports exports = {
-	MODULE_NAME,	 /* module name */
+	MODULE_NAME,     /* module name */
 	DEFAULT_DLFLAGS, /* dlopen flags */
-	cmds,			 /* exported functions */
-	params,			 /* exported parameters */
-	0,				 /* RPC method exports */
-	mod_pvs,		 /* exported pseudo-variables */
-	0,				 /* response handling function */
-	mod_init,		 /* module initialization function */
-	0,				 /* per-child init function */
-	mod_destroy		 /* module destroy function */
+	mod_cmds,        /* exported functions */
+	mod_params,      /* exported parameters */
+	0,               /* RPC method exports */
+	mod_pvs,         /* exported pseudo-variables */
+	0,               /* response handling function */
+	mod_init,        /* module initialization function */
+	0,               /* per-child init function */
+	mod_destroy      /* module destroy function */
 };
 /* clang-format on */
 
