@@ -7,6 +7,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -127,42 +129,37 @@ static int mod_child_init(int rank);
  * log a useful message and kill the AgentX Sub-Agent child process */
 static void mod_destroy(void);
 
+/* clang-format off */
 /*!
  * This structure defines the SNMPStats parameters that can be configured
  * through the kamailio.cfg configuration file.
  */
 static param_export_t mod_params[] = {
-		{"sipEntityType", PARAM_STRING | USE_FUNC_PARAM,
-				(void *)handleSipEntityType},
-		{"MsgQueueMinorThreshold", INT_PARAM | USE_FUNC_PARAM,
-				(void *)set_queue_minor_threshold},
-		{"MsgQueueMajorThreshold", INT_PARAM | USE_FUNC_PARAM,
-				(void *)set_queue_major_threshold},
-		{"dlg_minor_threshold", INT_PARAM | USE_FUNC_PARAM,
-				(void *)set_dlg_minor_threshold},
-		{"dlg_major_threshold", INT_PARAM | USE_FUNC_PARAM,
-				(void *)set_dlg_major_threshold},
-		{"snmpgetPath", PARAM_STRING | USE_FUNC_PARAM,
-				(void *)set_snmpget_path},
-		{"snmpCommunity", PARAM_STRING | USE_FUNC_PARAM,
-				(void *)set_snmp_community},
-		{"snmpVersion", PARAM_STRING | USE_FUNC_PARAM,
-				(void *)set_snmp_version},
-		{"export_registrar", INT_PARAM, &snmp_export_registrar}, {0, 0, 0}};
-
+	{"sipEntityType", PARAM_STRING | PARAM_USE_FUNC, (void *)handleSipEntityType},
+	{"MsgQueueMinorThreshold", PARAM_INT | PARAM_USE_FUNC, (void *)set_queue_minor_threshold},
+	{"MsgQueueMajorThreshold", PARAM_INT | PARAM_USE_FUNC, (void *)set_queue_major_threshold},
+	{"dlg_minor_threshold", PARAM_INT | PARAM_USE_FUNC, (void *)set_dlg_minor_threshold},
+	{"dlg_major_threshold", PARAM_INT | PARAM_USE_FUNC, (void *)set_dlg_major_threshold},
+	{"snmpgetPath", PARAM_STRING | PARAM_USE_FUNC, (void *)set_snmpget_path},
+	{"snmpCommunity", PARAM_STRING | PARAM_USE_FUNC, (void *)set_snmp_community},
+	{"snmpVersion", PARAM_STRING | PARAM_USE_FUNC, (void *)set_snmp_version},
+	{"export_registrar", PARAM_INT, &snmp_export_registrar},
+	{0, 0, 0}
+};
 
 struct module_exports exports = {
-		SNMPSTATS_MODULE_NAME, /* module name */
-		DEFAULT_DLFLAGS,	   /* dlopen flags */
-		0,					   /* exported functions */
-		mod_params,			   /* exported parameters */
-		0,					   /* exported rpc functions */
-		0,					   /* exported pseudo-variables */
-		0,					   /* reply processing function */
-		mod_init,			   /* module init function */
-		mod_child_init,		   /* per-child init function */
-		mod_destroy			   /* module destroy function */
+	SNMPSTATS_MODULE_NAME, /* module name */
+	DEFAULT_DLFLAGS, /* dlopen flags */
+	0,               /* exported functions */
+	mod_params,      /* exported parameters */
+	0,               /* exported rpc functions */
+	0,               /* exported pseudo-variables */
+	0,               /* response handling function */
+	mod_init,        /* module init function */
+	mod_child_init,  /* per-child init function */
+	mod_destroy      /* module destroy function */
 };
+/* clang-format on */
 
 /*!
  * The module will fork off a child process to run an snmp command via execve().
