@@ -43,6 +43,7 @@ struct cfg_group_tls default_tls_cfg = {
 		0,						  /* require_certificate */
 		STR_STATIC_INIT("off"),	  /* verify_client */
 		STR_NULL, /* private_key (default value set in fix_tls_cfg) */
+		STR_NULL, /* private_key_password */
 		STR_NULL, /* ca_list (default value set in fix_tls_cfg) */
 		STR_NULL, /* ca_path (default value set in fix_tls_cfg) */
 		STR_NULL, /* crl (default value set in fix_tls_cfg) */
@@ -163,6 +164,8 @@ cfg_def_t tls_cfg_def[] = {{"force_run", CFG_VAR_INT | CFG_READONLY, 0, 1, 0, 0,
 				"name of the file containing the private key (pem format), if "
 				"not"
 				" contained in the certificate file"},
+		{"private_key_password", CFG_VAR_STR | CFG_READONLY, 0, 0, 0, 0,
+				"the password for the private key"},
 		{"ca_list", CFG_VAR_STR | CFG_READONLY, 0, 0, 0, 0,
 				"name of the file containing the trusted CA list (pem format)"},
 		{"ca_path", CFG_VAR_STR | CFG_READONLY, 0, 0, 0, 0,
