@@ -27,25 +27,26 @@
 #include "../../core/dprint.h"
 #include "domain.h"
 
-typedef struct domain_api {
+typedef struct domain_api
+{
 	is_domain_local_f is_domain_local;
 } domain_api_t;
 
-typedef int (*bind_domain_f)(domain_api_t* api);
-int bind_domain(domain_api_t* api);
+typedef int (*bind_domain_f)(domain_api_t *api);
+int bind_domain(domain_api_t *api);
 
-static inline int load_domain_api(domain_api_t* api)
+static inline int load_domain_api(domain_api_t *api)
 {
 	bind_domain_f bind_domain;
 
 	bind_domain = (bind_domain_f)find_export("bind_domain", 0, 0);
 
-	if (bind_domain == NULL) {
+	if(bind_domain == NULL) {
 		ERR("Cannot import bind_domain function from domain module\n");
 		return -1;
 	}
 
-	if (bind_domain(api) == -1) {
+	if(bind_domain(api) == -1) {
 		return -1;
 	}
 	return 0;
