@@ -3,6 +3,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -50,10 +52,10 @@ void ul_set_xavp_contact_clone(int v)
 }
 
 /*!
- * \brief Store xavp list per contact
+ * \brief Store xavp list per contact from core, update existing contact as well
  * \param _c contact structure
  */
-void ucontact_xavp_store(ucontact_t *_c)
+static void ucontact_xavp_store(ucontact_t *_c)
 {
 	sr_xavp_t *xavp;
 	if(_c == NULL)
@@ -62,12 +64,15 @@ void ucontact_xavp_store(ucontact_t *_c)
 		return;
 	if(ul_xavp_contact_name.s == NULL)
 		return;
-	/* remove old list if it is set -- update case */
-	if(_c->xavp)
-		xavp_destroy_list(&_c->xavp);
+	/* XAVP from core */
 	xavp = xavp_get(&ul_xavp_contact_name, NULL);
-	if(xavp == NULL)
+	if(xavp == NULL) {
 		return;
+	}
+	/* remove old xavp if it is set -- update case */
+	if(_c->xavp) {
+		xavp_destroy_list(&_c->xavp);
+	}
 	/* clone the xavp found in core */
 	LM_DBG("trying to clone per contact xavps\n");
 	_c->xavp = xavp_clone_level_nodata(xavp);
@@ -124,6 +129,15 @@ ucontact_t *new_ucontact(
 		if(shm_str_dup(&c->instance, &_ci->instance) < 0)
 			goto error;
 	}
+	/* we got a xavp from e.g. DMQ */
+	if(_ci->xavp) {
+		/* destroy the existing contact xavp */
+		if(c->xavp) {
+			xavp_destroy_list(&c->xavp);
+		}
+		/* clone the DMQ xavp because it will be destroyed */
+		c->xavp = xavp_clone_level_nodata(_ci->xavp);
+	}
 
 	c->domain = _dom;
 	c->aor = _aor;
@@ -141,6 +155,8 @@ ucontact_t *new_ucontact(
 	c->tcpconn_id = _ci->tcpconn_id;
 	c->server_id = _ci->server_id;
 	c->keepalive = (_ci->cflags & ul_nat_bflag) ? 1 : 0;
+
+	/* Use core xavp if set, otherwise does nothing */
 	ucontact_xavp_store(c);
 
 
@@ -317,6 +333,16 @@ int mem_update_ucontact(ucontact_t *_c, ucontact_info_t *_ci)
 		_c->path.len = 0;
 	}
 
+	/* we got a xavp from e.g. DMQ */
+	if(_ci->xavp) {
+		/* destroy the existing contact xavp */
+		if(_c->xavp) {
+			xavp_destroy_list(&_c->xavp);
+		}
+		/* clone the DMQ xavp because it will be destroyed */
+		_c->xavp = xavp_clone_level_nodata(_ci->xavp);
+	}
+	/* Use core xavp if set, otherwise does nothing */
 	ucontact_xavp_store(_c);
 
 	_c->sock = _ci->sock;
@@ -1028,6 +1054,11 @@ int db_update_ucontact_ruid(ucontact_t *_c)
 		return -1;
 	}
 
+	if(ul_dbh == NULL) {
+		LM_ERR("database connection handle not initialized\n");
+		return -1;
+	}
+
 	n1 = 0;
 	keys1[n1] = &ul_ruid_col;
 	vals1[n1].type = DB1_STR;
@@ -1755,9 +1786,11 @@ int uldb_delete_attrs(str *_dname, str *_user, str *_domain, str *_ruid)
 	str tname;
 	db_key_t keys[3];
 	db_val_t vals[3];
+	int n = 0;
 
-	if(ul_db_ops_ruid == 1)
+	if(ul_db_ops_ruid == 1 && _ruid) {
 		return uldb_delete_attrs_ruid(_dname, _ruid);
+	}
 
 	LM_DBG("trying to delete location attributes\n");
 
@@ -1776,22 +1809,26 @@ int uldb_delete_attrs(str *_dname, str *_user, str *_domain, str *_ruid)
 	tname.s = tname_buf;
 	tname.len = _dname->len + 6;
 
-	keys[0] = &ulattrs_user_col;
-	keys[1] = &ulattrs_ruid_col;
-	keys[2] = &ulattrs_domain_col;
+	keys[n] = &ulattrs_user_col;
+	vals[n].type = DB1_STR;
+	vals[n].nul = 0;
+	vals[n].val.str_val = *_user;
+	n++;
 
-	vals[0].type = DB1_STR;
-	vals[0].nul = 0;
-	vals[0].val.str_val = *_user;
-
-	vals[1].type = DB1_STR;
-	vals[1].nul = 0;
-	vals[1].val.str_val = *_ruid;
+	if(_ruid) {
+		keys[n] = &ulattrs_ruid_col;
+		vals[n].type = DB1_STR;
+		vals[n].nul = 0;
+		vals[n].val.str_val = *_ruid;
+		n++;
+	}
 
 	if(ul_use_domain) {
-		vals[2].type = DB1_STR;
-		vals[2].nul = 0;
-		vals[2].val.str_val = *_domain;
+		keys[n] = &ulattrs_domain_col;
+		vals[n].type = DB1_STR;
+		vals[n].nul = 0;
+		vals[n].val.str_val = *_domain;
+		n++;
 	}
 
 	if(ul_dbf.use_table(ul_dbh, &tname) < 0) {
@@ -1799,7 +1836,7 @@ int uldb_delete_attrs(str *_dname, str *_user, str *_domain, str *_ruid)
 		return -1;
 	}
 
-	if(ul_dbf.delete(ul_dbh, keys, 0, vals, (ul_use_domain) ? (3) : (2)) < 0) {
+	if(ul_dbf.delete(ul_dbh, keys, 0, vals, n) < 0) {
 		LM_ERR("deleting from database failed\n");
 		return -1;
 	}
