@@ -1,15 +1,17 @@
-INSERT INTO version (table_name, table_version) values ('trusted','5');
 CREATE TABLE trusted (
     id INTEGER PRIMARY KEY NOT NULL,
     src_ip VARCHAR(50) NOT NULL,
     proto VARCHAR(4) NOT NULL,
     from_pattern VARCHAR(64) DEFAULT NULL,
-    tag VARCHAR(64)
+    ruri_pattern VARCHAR(64) DEFAULT NULL,
+    tag VARCHAR(64),
+    priority INTEGER DEFAULT 0 NOT NULL
 );
 
 CREATE INDEX trusted_peer_idx ON trusted (src_ip);
 
-INSERT INTO version (table_name, table_version) values ('address','6');
+INSERT INTO version (table_name, table_version) values ('trusted','6');
+
 CREATE TABLE address (
     id INTEGER PRIMARY KEY NOT NULL,
     grp INTEGER DEFAULT 1 NOT NULL,
@@ -19,3 +21,5 @@ CREATE TABLE address (
     tag VARCHAR(64)
 );
 
+INSERT INTO version (table_name, table_version) values ('address','6');
+
