@@ -1,10 +1,11 @@
-INSERT INTO version (table_name, table_version) values ('trusted','5');
 CREATE TABLE trusted (
     id NUMBER(10) PRIMARY KEY,
     src_ip VARCHAR2(50),
     proto VARCHAR2(4),
     from_pattern VARCHAR2(64) DEFAULT NULL,
-    tag VARCHAR2(64)
+    ruri_pattern VARCHAR2(64) DEFAULT NULL,
+    tag VARCHAR2(64),
+    priority NUMBER(10) DEFAULT 0 NOT NULL
 );
 
 CREATE OR REPLACE TRIGGER trusted_tr
@@ -17,7 +18,8 @@ BEGIN map2users('trusted'); END;
 /
 CREATE INDEX trusted_peer_idx  ON trusted (src_ip);
 
-INSERT INTO version (table_name, table_version) values ('address','6');
+INSERT INTO version (table_name, table_version) values ('trusted','6');
+
 CREATE TABLE address (
     id NUMBER(10) PRIMARY KEY,
     grp NUMBER(10) DEFAULT 1 NOT NULL,
@@ -35,3 +37,5 @@ END address_tr;
 /
 BEGIN map2users('address'); END;
 /
+INSERT INTO version (table_name, table_version) values ('address','6');
+
